<?php
/**
 * Plugin Name: HOB Acte-Publicité
 * Version: 1.2.2
 * Plugin URI: https://www.hob-france.com/
 * Description: Publiez et triez facilement vos contenus PDF pour respecter les normes législatives.
 * Author: HOB France Services
 * Author URI: https://www.hob-france.com/
 * Requires at least: 6.0
 * Tested up to: 6.0.1
 * Text Domain: hob-ap
 * Domain Path: /languages
 *
 * @package WordPress
 * @author HOB France Services
 * @since 1.0.0
 */

/* Récupération de la version actuel de l'extension */
$plugin_data = get_file_data(__FILE__, array('Version' => 'Version'), false);


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $wpdb ;
ob_start();

/* Création des variables globales pour les chemins de fichiers et la version */
define( 'HOB_AP_URL', plugin_dir_path( __FILE__ ) );
define( 'HOB_AP_URL_SCRIPT', plugin_dir_url( __FILE__ ) );
define( 'HOB_AP_VERSION', $plugin_data['Version'] );

/* Liaison pour la traduction de l'extension */
add_action( 'plugins_loaded', 'hob_ap_init' );

/**
 * hob_ap_init
 *
 * @return void
*/
function hob_ap_init() {
    add_action( 'init', 'wpdocs_load_hob_ap' );
}

/**
 * wpdocs_load_hob_ap
 *
 * @return void
 */
function wpdocs_load_hob_ap() {
  load_plugin_textdomain( 'WP_HOB_PUBLICITE', '', dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
}

/* Récupération des classes nécessaires pour le fonctionnement de l'extension */
include( HOB_AP_URL . 'includes/hob_ap_setup.php');
include( HOB_AP_URL . 'includes/hob_ap_settings.php');

$hob_ap_settings = new Hob_ap_settings;

include( HOB_AP_URL . 'includes/Hob_ap_request.php');


/* Classe d'activation et de désactivation du plugin */
register_activation_hook(   __FILE__, array( 'Hob_ap_setup', 'on_activation' ) );
register_deactivation_hook( __FILE__, array( 'Hob_ap_setup', 'on_deactivation' ) );

add_action( 'plugins_loaded', array( 'Hob_ap_setup', 'init' ) );


// Check de la licence
$hob_ap_statut = $hob_ap_settings->check_licence();
define( 'HOB_AP_STATUT', $hob_ap_statut );


// Lors de l'activation de l'extension, une méthode de la class setting est activée pour mettre les valeurs par défaut
function register_hob_ap_plugin_settings() {
	/* Configuration */
	register_setting( 'hob_ap_plugin_settings-token', 'hob-ap-token');
  }
add_action( 'admin_init', 'register_hob_ap_plugin_settings' );



// Création d'un onglet pour activer la licence
function licence_menu() {
    add_submenu_page(
        'edit.php?post_type=hob-ap',
        __( 'Configuration', 'textdomain' ),
        __( 'Activation Licence', 'textdomain' ),
        'manage_options',
        'hob-ap_licencekey',
        'licence_menu_callback'
    );
}
add_action('admin_menu', 'licence_menu');


// Callback permettant d'afficher le contenu de notre page Configuration
function licence_menu_callback() { 
?>

<h1 class=><?php _e( 'Configuration', 'textdomain' ); ?></h1>
    <div class="ap-description">
	    <div class="card">
    	    <div class="card-body">
            	<div class="presentation_statut">
				<!-- Si pas de clé valide, aucune fonctionnalité ne sera disponible -->
				<?php if(HOB_AP_STATUT == null){ ?>
					<div class="alertbar" role="alert">
						<p>Clé d'activation non valide ou expirée.
						<a href="https://www.joomhob.com/extensions-joomla/product/9-hob-actes-publicite.html" target="_blank">Vous pouvez choisir de souscrire à une licence en cliquant ici.</a></p>
					</div>
				<?php
				} 
				
				// Alerte qui change avec une clé active
				else if (HOB_AP_STATUT != null){?>
					<div class="alertbar2">Votre licence annuelle est active.</div>
					<div class="alertbar3">Merci de rafraichir vos liens via "Réglages->Permaliens" afin d'afficher le contenu de vos publications.</div>
				<?php
				}
				?>
                  
            	<div class="hob_propos">
                	<h2><?= __('A propos de HOB France Services','WP_HOB_PUBLICITE') ?></h2>
                   	<p><?= __('  HOB France Services
					est une agence de communication numérique, basée sur Sophia Antipolis et Paris. Nos équipes sont
					de véritables experts des projets Wordpress. Création de sites internet, maintenance, développement
					d’extensions et formation, nous accompagnons nos clients dans toutes les phases de la
					réalisation de leurs projets digitaux.','WP_HOB_PUBLICITE') ?></p>
                   	<p><a href="https://www.hob-france.com/" target="_blank"><img class="hob_logohob" src="https://www.hob-france.com/images/logo/logo_hob_72x72.png"></a>
				</div>
			</div>
			<h1 class="h1_url">Clé d'activation</h1>  
            <form method="post" action="<?= get_site_url() ?>/wp-admin/edit.php?post_type=hob-ap&page=hob-ap_licencekey">
                <input type="text" name="token_hob_ap" id="token_hob_ap" placeholder="Clé licence"  value="<?= get_option( 'hob-ap-token'); ?>"required>
                <button type="submit" id="hob_ap_button">Enregistrer</button>
            </form>
        </div>

		<!-- Fonctionnalité débloquée grace à l'activation de la licence -->
		<?php if (HOB_AP_STATUT != null){?>
			<p class="tips">Votre licence est maintenant active. Afin de profiter pleinement de notre plugin dans les meilleures conditions, nous vous invitons à créer dès à présent des "rubriques" et "types" avant d'ajouter une publication.</p>
	</div>

<!-- Modification du slug/url -->
<h1 class=><?php _e( 'Affichage', 'textdomain' ); ?></h1>
	<div class="ap-description">
		<div class="card">
			<div class="card-body">
				<h1 class="h1_url">URL permettant d'afficher les actes et publicités</h1>  
					<form method="post" action="<?= get_site_url() ?>/wp-admin/edit.php?post_type=hob-ap&page=hob-ap_licencekey">
						<p>Vous pouvez configurer ci-dessous l'url sous laquelle apparaitra la page des publications. Cette page sera disponible à l'adresse suivante: "votresite/nomdelapage". </p>
						
						<?php
						$url_field = esc_html($_POST['url_hob_ap']);
						$url_custom = get_site_url().'/'. $url_field;
						$url_options = isset($_POST['url_hob_ap']) ? $_POST['url_hob_ap'] : "";
						?>

						<input type="text" name="url_hob_ap" id="url_hob_ap" placeholder="nomdelapage"  value="<?php echo $url_options; ?>" required>
						<button type="submit" id="hob_ap_button1">Enregistrer</button>
					</form>

					<?php if (isset($_POST['url_hob_ap']) != null){?>
							<p class="tips">Votre URL a bien été enregistrée. Pour que la modification soit effective, n'oubliez pas de sauvegarder vos permaliens dans "Réglages -> Permaliens" ou <a href="<?= get_site_url() ?>/wp-admin/options-permalink.php" target="_blank">ici</a>, puis cliquez sur "Enregistrer les modifications". Après avoir sauvegardé vos permaliens, vous pourrez retrouver l'ensemble de vos publications à l'adresse suivante: <a href="<?= $url_custom ?>" target="_blank">Mes actes et publicités</a></p>
					<?php
						}

					// Stockage de l'url en base de données pour pouvoir rewrite le slug
					if (isset($_POST['url_hob_ap'])) {
						update_option( 'url_hob_ap', $url_field, 'yes');
					}
					?>

					<!-- Choix du tracking -->
					<div class="hob_tracking">
						<h1 class="h1_url">Affichage du nombre de vues en front-end</h1>
							<p>Souhaitez-vous afficher le nombre de vues des documents à tous les utilisateurs?</p> 
								<fieldset>
									<div>
										<form method="post" action="<?= get_site_url() ?>/wp-admin/edit.php?post_type=hob-ap&page=hob-ap_licencekey">     
											<input type="radio" id="yes_view" name="no_view" value="0"checked>
											<label for="oui">Oui</label>
									</div>
							<div>
								<input type="radio" id="no_view" name="no_view" value="1">
								<label for="no_view">Non</label>
							</div>
						</fieldset>						
							<button type="submit" id="hob_ap_button1">Enregistrer</button>

						<?php 					
							if (isset($_POST["no_view"]) != null) {
								update_option( 'hob_ap_click', $_POST['no_view']); ?>
								<p class="tips">Votre choix a bien été enregistré.</p>
						<?php
							}
						?>
										</form>
					</div>
					<!-- Description personnalisable -->
					<div class="hob_description">
							<h1 class="h1_url">Description (optionnel)</h1>
							<p>Vous pouvez configurer un titre ainsi qu'une description qui seront affichés sur la page recueillant les publications.</p> 
							<form method="post" action="<?= get_site_url() ?>/wp-admin/edit.php?post_type=hob-ap&page=hob-ap_licencekey">
							
						<?php
						$content   = '';
						$editor_id = 'description_hob_ap';
						$settings  = array( 'media_buttons' => false );
						
						wp_editor( $content, $editor_id, $settings );
						?>
								
								<button type="submit" id="hob_ap_button1">Enregistrer</button>
							</form>
						</div>
						<?php
							if (isset($_POST['description_hob_ap']) != null) {
								update_option( 'description_hob_ap', $_POST['description_hob_ap'], 'yes'); ?>
								<p class="tips">Votre description a bien été enregistrée.</p>
						<?php
						} ?>
		</div>
					</div>
					</div>
				<?php }
				?>		
    <?php
}


// Charge le css pour le back en appelant la page admin
if(is_admin()){
	include( HOB_AP_URL . 'admin/admin.php');
}


// Hook permettant d'ajouter une page d'archive sur un thème préexistant
function get_hob_ap_archive_template( $archive_template ) {
    if ( is_post_type_archive ( 'hob-ap' ) ) {
         $archive_template = dirname( __FILE__ ) . '/archive-hob-ap.php';
    }
    return $archive_template;
}
add_filter( 'archive_template', 'get_hob_ap_archive_template' ) ;


// Hook permettant d'ajouter une search-page sur un thème préexistant
function get_hob_ap_search_template( $search_template ) {
    if ( is_post_type_archive ( 'hob-ap' ) ) {
         $search_template = dirname( __FILE__ ) . '/search-hop-ap.php';
    }
    return $search_template;
}
add_filter( 'search_template', 'get_hob_ap_search_template' ) ;

// Hook permettant de personnaliser le front de notre single-post
function get_single_post_template( $single_template ) {
    global $post;
    if ( 'hob-ap' === $post->post_type ) {
        $single_template = dirname( __FILE__ ) . '/single-hob-ap.php';
    }
    return $single_template;
}
add_filter( 'single_template', 'get_single_post_template' ); 

// Hook pour charger notre fichier.css en front
function loading_css() {
	wp_enqueue_style( 'front-css', plugin_dir_url( __FILE__ ) . '/asset/css/front.css' );
}
add_action( 'wp_enqueue_scripts', 'loading_css' );



	/* Fonction pour créer le custom post type 'hob-publicité' */
	function hob_post_type() {

		// On rentre les différentes dénominations de notre custom post type qui seront affichées dans l'administration
		$labels = array(
			// Le nom au pluriel
			'name'                => _x( 'HOB Actes-Publicités', 'Post Type General Name'),
			// Le nom au singulier
			'singular_name'       => _x( 'HOB Publicité', 'Post Type Singular Name'),
			// Le libellé affiché dans le menu
			'menu_name'           => __( 'HOB ActePublicité'),
			// Les différents libellés de l'administration
			'all_items'           => __( 'Toutes les publications'),
			'view_item'           => __( 'Voir les publications'),
			'add_new_item'        => __( 'Ajouter une nouvelle publication'),
			'add_new'             => __( 'Ajouter une publication'),
			'edit_item'           => __( 'Editer la publication'),
			'update_item'         => __( 'Modifier la publication'),
			'insert_into_item' 	  => __('Insérer dans HOB Publication'),
			'uploaded_to_this_item' => __('Uploader la publication'),
			'search_items'        => __( 'Rechercher une publication'),
			'not_found'           => __( 'Non trouvée'),
			'not_found_in_trash'  => __( 'Non trouvée dans la corbeille'),
		);
		
		// On peut définir ici d'autres options pour notre custom post type
		$args = array(
			'label'               => __( 'HOB Acte-Publicité'),
			'description'         => __( 'Organisez vos PDF protégés'),
			'menu_icon'      	  =>  plugins_url('/asset/img/logo.png', __FILE__),
			'labels'              => $labels,
			// On définit les options disponibles dans l'éditeur de notre custom post type ( un titre, un auteur...)
			// 'supports'            => array( 'title', 'editor', 'excerpt', 'author', 'thumbnail', 'comments', 'revisions', 'custom-fields', ),
			'supports'            => array( 'title'),
			
			// Différentes options supplémentaires
			'show_in_rest' => true,
			'hierarchical'        => true,
			'public'              => true,
			'has_archive'         => true,

			'rewrite'			  => array( 'slug' => get_option( 'url_hob_ap' )), // Faire un imput sur la page licence, et rendre ça configurable via un $_GET[option]
		);
		
		// Enregistrement du custom post type "hob-ap" et ses arguments
		register_post_type( 'hob-ap', $args );
		
	}

add_action( 'init', 'hob_post_type', 0 );


if(HOB_AP_STATUT != null){

add_action( 'init', 'hob_add_taxonomies', 0 );
}

// Création des taxonomies personnalisées
function hob_add_taxonomies() {
	
	// Taxonomie Délibération
	// On déclare ici les différentes dénominations de notre taxonomie qui seront affichées et utilisées dans l'administration de WordPress
	$labels_delib = array(
		'name'              			=> _x( 'N° de délibération', 'taxonomy general name'),
		'singular_name'     			=> _x( 'N° de délibération', 'taxonomy singular name'),
		'search_items'      			=> __( 'Chercher une délibération'),
		'all_items'        				=> __( 'Toutes les délibérations'),
		'edit_item'         			=> __( 'Editer les paramètres de la délibération'),
		'update_item'       			=> __( 'Mettre à jour la délibération'),
		'add_new_item'     				=> __( 'Ajouter une nouvelle délibération'),
		'new_item_name'     			=> __( 'N° de la délibération'),
		'menu_name'         			=> __( 'N° de délibération'),
	);

	$args_delib = array(
	// Si 'hierarchical' est défini à false, notre taxonomie se comportera comme une étiquette standard
		'hierarchical'      => false,
		'labels'            => $labels_delib,
		'show_ui'           => true,
		'show_in_menu' 		=> false,
		'show_in_rest'      => true,
		'show_admin_column' => true,
		'query_var'         => true,
		'meta_box_cb'		=> 'hob_add_deliberation_number',
		'meta_box_sanitize_cb'=> 666,
		'rewrite'           => array( 'slug' => 'hob_deliberation' ),
		'has_archive' => true,
	);
	register_taxonomy( 'hob_deliberation', 'hob-ap', $args_delib );


  // Taxonomie Recueil Administratif
	$args_ra = array(
		'hierarchical'          => false,
    	'label'            		=>__( 'R.A'),
		'show_ui'               => true,
		'show_in_menu' 			=> false,
		'show_in_rest'			=> true,
		'show_admin_column'     => true,
		'query_var'             => true,
		'meta_box_cb' 			=> 'checkbox_RA',
		'rewrite'               => array( 'slug' => 'hob_ra' ),
	);
	register_taxonomy( 'hob_ra', 'hob-ap', $args_ra );	


  // Taxonomie Rubrique
  $labels_rubrique = array(
	'name'              			=> _x( 'Rubrique', 'taxonomy general name'),
	'singular_name'     			=> _x( 'Rubrique', 'taxonomy singular name'),
	'search_items'      			=> __( 'Chercher une rubrique'),
	'all_items'        				=> __( 'Toutes les rubriques'),
	'edit_item'         			=> __( 'Editer une rubrique'),
	'update_item'       			=> __( 'Mettre à jour la rubrique'),
	'add_new_item'     				=> __( 'Ajouter une nouvelle rubrique'),
	'new_item_name'     			=> __( 'Rubrique'),
	'menu_name'         			=> __( 'Rubriques'),
	);

	$args_rubrique = array(
		'hierarchical'          => true,
    	'labels'            	=> $labels_rubrique,
		'show_ui'               => true,
		'show_in_menu' 			=> true,
		'show_in_rest'			=> true,
		'show_admin_column'     => true,
		'query_var'             => true,
		'rewrite'               => array( 'slug' => 'hob_rubrique' ),
		"meta_box_cb" 			=> 'taxonomy_select_meta_box', // La meta_box_cb permet de customiser l'apparence de notre taxonomie en back office
		"show_in_quick_edit" => false,
		'menu_position' => 0,

	);
	register_taxonomy ('hob_rubrique', 'hob-ap', $args_rubrique );	


  // Taxonomie Date du conseil
	$args_conseildate = array(
		'hierarchical'          => false,
    	'label'                 =>__( 'Date du conseil'),
		'show_ui'               => true,
		'show_in_menu' 			=> false,
		'show_in_rest'			=> true,
		'show_admin_column'     => true,
		'meta_box_cb' 			=> 'post_meta_box_date_conseil',
		'query_var'             => true,
		'rewrite'               => array( 'slug' => 'hob_date_conseil'),
	);
	register_taxonomy( 'hob_date_conseil', 'hob-ap', $args_conseildate );	


  // Taxonomie N° de registre
	$args_registry = array(
		'hierarchical'          => false,
    	'label'                 =>__( 'N° de registre'),
		'show_ui'               => true,
		'show_in_menu' 			=> false,
		'show_in_rest'			=> true,
		'show_admin_column'     => true,
		'query_var'             => true,
		'meta_box_cb'			=> 'hob_add_register_number',
		'rewrite'               => array( 'slug' => 'hob_register' ),
	);
	register_taxonomy( 'hob_register', 'hob-ap', $args_registry );	


  // Taxonomie Page
	$args_page = array(
		'hierarchical'          => false,
    	'label'                 =>__( 'Page du registre'),
		'show_ui'               => true,
		'show_in_menu' 			=> false,
		'show_in_rest'			=> true,
		'show_admin_column'     => true,
		'query_var'             => true,
		'meta_box_cb' 			=> 'hob_add_page',
		'rewrite'               => array( 'slug' => 'hob_page' ),
	);
	register_taxonomy( 'hob_page', 'hob-ap', $args_page );	


  // Taxonomie Type
  $labels_typecat = array(
	'name'              			=> _x( 'Type', 'taxonomy general name'),
	'singular_name'     			=> _x( 'Type', 'taxonomy singular name'),
	'search_items'      			=> __( 'Chercher un type'),
	'all_items'        				=> __( 'Tous les types'),
	'edit_item'         			=> __( 'Editer un type'),
	'update_item'       			=> __( 'Mettre à jour le type'),
	'add_new_item'     				=> __( 'Ajouter un nouveau type'),
	'new_item_name'     			=> __( 'Type'),
	'menu_name'         			=> __( 'Types'),
);

	$args_typecat = array(
		'hierarchical'          => true,
    	'labels'            	=> $labels_typecat,
		'show_ui'               => true,
		'show_in_menu' 			=> true,
		'show_in_rest'			=> true,
		'show_admin_column'     => true,
		'query_var'             => true,
		'rewrite'               => array( 'slug' => 'hob_typecat' ),
		"meta_box_cb" 			=> 'taxonomy_select_meta_box',
		"show_in_quick_edit" => false,


	);
	register_taxonomy( 'hob_typecat', 'hob-ap', $args_typecat );	


  // Taxonomie Fichier
	$args_file = array(
		'hierarchical'          => false,
    	'label'                 =>__( 'Fichier'),
		'show_ui'               => true,
		'show_in_menu' 			=> false,
		'show_in_rest'			=> true,
		'show_admin_column'     => true,
		'query_var'             => true,
		'capability_type' 		=> 'attachment',
		'rewrite'               => array( 'slug' => 'hob_file' ),
		'meta_box_cb'			=> 'additional_category_fields'
	);
	register_taxonomy( 'hob_file', 'hob-ap', $args_file );	
  
}

// Sauvegarde du champ date du conseil
function save_post_meta_boxes(){
    global $post;
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
    		return;
     }
	if($post){
		update_post_meta( $post->ID, "hob_date_conseil", sanitize_text_field( $_POST[ "hob_date_conseil" ] ) );
	}   
}
add_action( 'save_post', 'save_post_meta_boxes' );


// Fonction Callback pour afficher le rendu
function post_meta_box_date_conseil(){
    global $post;
    $custom = get_post_custom( $post->ID ); 
    
    $advertisingCategory = isset($custom[ "hob_date_conseil" ]) ? $custom[ "hob_date_conseil" ][ 0 ] : '';
    echo "<input type=\"date\" name=\"hob_date_conseil\" value=\"".$advertisingCategory."\" placeholder=\"Event Date\">";

	wp_insert_term( $advertisingCategory, 'hob_date_conseil' ); 

	global $wpdb;
	$results = $wpdb->get_results( "SELECT MAX(term_taxonomy_id) as id FROM wp_term_taxonomy WHERE taxonomy = 'hob_date_conseil'", OBJECT);
	$category_id = $results[0]->id; 
	wp_set_object_terms( $post->ID, intval( $category_id ), 'hob_date_conseil' ); 	
}

/**
 * Ajout de selectbox dans la taxonomie
 *
 * @param WP_Post $post
 * @param array $box
 */
function taxonomy_select_meta_box($post, $box) {
    $defaults = array('taxonomy' => 'category');
    
    if (!isset($box['args']) || !is_array($box['args']))
        $args = array();
    else
        $args = $box['args'];
    
    extract(wp_parse_args($args, $defaults), EXTR_SKIP);
    
    $tax = get_taxonomy($taxonomy); // Récupération des taxonomies rubriques et types
    $selected = wp_get_object_terms($post->ID, $taxonomy, array('fields' => 'ids'));


    $hierarchical = $tax->hierarchical;
    ?>
    <div id="taxonomy-<?php echo $taxonomy; ?>" class="selectdiv">
        <?php if (current_user_can($tax->cap->edit_terms)): ?>
        <?php 
            if ($hierarchical) {
                wp_dropdown_categories(array(
                   'taxonomy' => $taxonomy,
                   'class' => 'selecteur',
                   'hide_empty' => 0, 
                   'name' => "tax_input[$taxonomy][]",
                   'selected' => count($selected) >= 1 ? $selected[0] : '',
                   'orderby' => 'name', 
                   'hierarchical' => 1, 
                   'show_option_all' => "",
                ));

				// var_dump($taxonomy);
				// exit;
            } else {

				
                ?>
                <select name="<?php echo "tax_input[$taxonomy][]"; ?>" class="selecteur" required>
                    <option value="0"></option>
                    <?php foreach (get_terms($taxonomy, array('hide_empty' => true)) as $term): ?>
                        <option value="<?php echo esc_attr($term->slug); ?>" <?php echo selected($term->term_id, count($selected) >= 1 ? $selected[0] : ''); ?>><?php echo esc_html($term->name); ?></option>
						
						
						<?php var_dump($taxonomy);
				 exit;?>
                    <?php endforeach; ?>
                </select>
                <?php 
            }
        ?>
        <?php endif; ?>
    </div>
    <?php
}

// Ajout de metadatas à la taxonomy N° de délibération
function hob_add_deliberation_number( $term, $taxonomy ) {
	$value = get_term_meta( $term->ID, 'hob_delib_number', true );

	echo '<div class="form-field">
	  <input type="text" name="hob_delib_number" id="hob_delib_number" value="'.$value.'"  />
	  <p>Entrez le numéro de délibération de votre publication.</p>
	</div>';
} 

  // Ajout metadata à taxonomy N° de registre
function hob_add_register_number( $term, $taxonomy ) {
	$value = get_term_meta( $term->ID, 'hob_register_number', true );

	echo '<div class="form-field">
	  <input type="text" name="hob_register_number" id="hob_register_number" value="'.$value.'"  />
	  <p>Entrez le numéro de registre de votre publication.</p>
	</div>';
} 

// Ajout metadata à taxonomy Page du registre
function hob_add_page( $term, $taxonomy ) {
	$value = get_term_meta( $term->ID, 'hob_page', true );

	echo '<div class="form-field">
	  <input type="text" name="hob_page" id="hob_page" value="'.$value.'"  />
	  <p>Entrez le numéro de la page de votre publication.</p>
	</div>';
} 

// Sauvegarde des metadatas en BDD
function hob_save_field_data( $term_id ) {

	if(isset($_POST[ 'hob_delib_number' ] )){
		$value = get_term_meta( $term_id, 'hob_delib_number', true ); // Récupération des metadonnées du term/taxonomy
		
		update_term_meta( $term_id,'hob_delib_number', sanitize_text_field( $_POST[ 'hob_delib_number' ] )); // Update des données du term
		update_post_meta( $term_id, "hob_delib_number", sanitize_text_field( $_POST[ "hob_delib_number" ] ) ); // Update des données du postmeta

		wp_insert_term( sanitize_text_field( $_POST[ "hob_delib_number" ] ), 'hob_deliberation' ); // Création d'un term du nom de l'input dans la taxonomy deliberation

		global $wpdb;
		$results = $wpdb->get_results( "SELECT MAX(term_taxonomy_id) as id FROM wp_term_taxonomy WHERE taxonomy = 'hob_deliberation'", OBJECT);
		$category_id = $results[0]->id; // Obtention de l'ID correspondant à l'étiquette nouvellement créée
	
		wp_set_object_terms( $term_id, intval( $category_id ), 'hob_deliberation' ); // Ajout de la relation entre le post, le term et la taxonomy
	}

	if(isset($_POST[ 'hob_register_number' ] )){
		$value = get_term_meta( $term_id, 'hob_register_number', true ); 		
		update_term_meta( $term_id,'hob_register_number', sanitize_text_field( $_POST[ 'hob_register_number' ] )); 
		update_post_meta( $term_id, "hob_register_number", sanitize_text_field( $_POST[ "hob_register_number" ] ) ); 
		wp_insert_term( sanitize_text_field( $_POST[ "hob_register_number" ] ), 'hob_register' ); 
		global $wpdb;
		$results = $wpdb->get_results( "SELECT MAX(term_taxonomy_id) as id FROM wp_term_taxonomy WHERE taxonomy = 'hob_register'", OBJECT);
		$category_id = $results[0]->id; // 
		wp_set_object_terms( $term_id, intval( $category_id ), 'hob_register' ); 
	}

	if(isset($_POST[ 'hob_page' ] )){
		$value = get_term_meta( $term_id, 'hob_page', true ); 		
		update_term_meta( $term_id,'hob_page', sanitize_text_field( $_POST[ 'hob_page' ] )); 
		update_post_meta( $term_id, "hob_page", sanitize_text_field( $_POST[ "hob_page" ] ) ); 
		wp_insert_term( sanitize_text_field( $_POST[ "hob_page" ] ), 'hob_page' ); 
		global $wpdb;
		$results = $wpdb->get_results( "SELECT MAX(term_taxonomy_id) as id FROM wp_term_taxonomy WHERE taxonomy = 'hob_page'", OBJECT);
		$category_id = $results[0]->id; // 
		wp_set_object_terms( $term_id, intval( $category_id ), 'hob_page' ); 
	}
}
add_action( 'save_post', 'hob_save_field_data' );  


// Enctype form-data poussé dans le post du formulaire nécessaire à l'upload d'un fichier
function edit_form_tag( ) {
    echo ' enctype="multipart/form-data"';
}
add_action( 'post_edit_form_tag' , 'edit_form_tag' );


// Ajout d'un upload de fichier dans notre post_type hob-ap
function additional_category_fields( $term, $tax ) {
    $uploadID   = get_term_meta( $term->ID, 'hob_file', true );             // Récupération de l'Attachment ID de la table 'post_meta' de la Database
    $feedback   = get_term_meta( $term->ID, 'hobfile_feedback', true );    // Récupération des feedbacks de l'upload de la table "options" de la Database
	$viewArray = get_post_meta( $term->ID, 'hob_click');
	$view = $viewArray[0];

?>

    <tr class="form-field">
        <td>
            <div id="catImage">	

                <!-- Création d'un nonce pour permettre la validation -->
                <input type="hidden" name="upload_meta_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

                <!-- Champ permettant à l'utilisateur d'uploader un fichier  -->
                Veuillez sélectionner votre fichier: <input type="file" name="hobfile" id="hobfile" value="" />

                <?php 
                  if( is_numeric( $uploadID ) ) :        				// Si notre $uploadID est un integer, on continue
                    $imageURL = wp_get_attachment_url( $uploadID );     // Récupération de l'ID de l'image, fonction WP
                ?>

                    <div id="uploaded_image">
                    	<!-- Lien renvoyant vers l'image obtenue-->
						<a href="<?php echo $imageURL; ?>" target="_blank"><img src="https://upload.wikimedia.org/wikipedia/commons/thumb/8/87/PDF_file_icon.svg/833px-PDF_file_icon.svg.png" width='40px' height='50px'>
						<!-- <?php bloginfo('url'); ?>/asset/img/pdf-icon.png" > -->
						</a><p class="invalid_doc">Document vu: <span style="font-weight:bold"><?= $view?> fois.</span></p> 					
                    </div>

                <!-- Si on a reçu un feedback car mauvais format, affichage de la réponse -->               
                <?php elseif( ! empty( $feedback ) ) : ?>
                    <p style="color:red;font-size:12px;font-weight;bold;font-style:italic;"><?php echo $feedback; ?></p>
                <?php endif; ?>

            </div>
            <span class="description"><?php _e( 'Seul le format .pdf est autorisé.' ); ?></span>
                <br />
                <br />

        </td> 
    </tr>

  <?php
    // Puisque le feedback a été affiché, on peut le supprimer en base de données
    delete_term_meta( $term->term_id, 'hobfile_feedback' );
}
add_action( 'post_edit_form_fields', 'additional_category_fields', 10, 2 ); 

/** Sauvegarde des metadonnées de l'upload de fichier **/
function save_category_fields( $term_id ) {

    // Sécurité supplémentaire avec le nonce, la taxonomy, et qu'il y ait bien un fichier uploadé pour avancer
    if(
      isset( $_POST['upload_meta_nonce'] ) && wp_verify_nonce( $_POST['upload_meta_nonce'], basename( __FILE__ ) ) &&
      isset( $_FILES['hobfile'] ) && !empty( $_FILES['hobfile'] )
    ) {
        $supportedTypes = array( 'application/pdf');                      
        $fileArray      = wp_check_filetype( basename( $_FILES['hobfile']['name'] ) ); 
        $fileType       = $fileArray['type'];   

        // Vérification de la correspondance des types du fichier
        if( in_array( $fileType, $supportedTypes ) ) {
			
            $uploadStatus = wp_handle_upload( $_FILES['hobfile'], array( 'test_form' => false ) );

            if( isset( $uploadStatus['file'] ) ) {
                require_once(ABSPATH . "wp-admin" . '/includes/file.php');
				
                // Ajout de l'image permettant l'accès à ses metadatas
                $imageID = wp_insert_attachment( array(
                        'post_mime_type'    => $uploadStatus['type'],
                        'post_title'        => preg_replace( '/\.[^.]+$/', '', basename( $uploadStatus['file'] ) ),
                        'post_content'      => '',
                        'post_status'       => 'publish'
                    ),
                    $uploadStatus['file']					
                );

				$regex = "/[^\/]*$/"; // Regex pour obtenir le nom du fichier

				$pdfname = preg_match($regex, ($uploadStatus['file']), $matches); // $matches correspond maintenant au nom du fichier	
				$filename = $matches[0];			

                // Création de l'attachment en metadonnées puis actualisation du fichier
                $attachmentData = wp_generate_attachment_metadata( $imageID, $uploadStatus['file'] );
                wp_update_attachment_metadata( $imageID,  $attachmentData );

                $existingImage = get_term_meta( $term_id, 'hobfile', true );        	// Récupération du fichier s'il existe deja
                if( ! empty( $existingImage ) && is_numeric( $existingImage ) ) {       // Suppression de l'attachment précédent pour l'actualiser.
                    wp_delete_attachment( $existingImage );
                }

				wp_insert_term( $filename, 'hob_file' ); 

				global $wpdb;
				$results = $wpdb->get_results( "SELECT MAX(term_taxonomy_id) as id FROM wp_term_taxonomy WHERE taxonomy = 'hob_file'", OBJECT);
				$category_id = $results[0]->id; // 
				wp_set_object_terms( $term_id, intval( $category_id ), 'hob_file' ); 

                update_term_meta( $term_id, 'hob_file', $imageID );                  // Actualisation des metas avec le nouvel attachment ID

				delete_term_meta( $term_id, 'hobfile_feedback' );                   // Doublecheck si un feedback meta existe, on le supprime dans ce cas
            }
            else {
                $uploadFeedback = 'Un problème est survenu avec votre upload, merci de contacter un Administrateur.'; 
            }
        }
        else {
            $uploadFeedback = "Votre fichier n'a pas été uploadé."."</br>"." 
			Format autorisé: PDF"; 
        }

        // Update our Feedback meta
        if( isset( $uploadFeedback ) ) {
            update_term_meta( $term_id, 'hobfile_feedback', $uploadFeedback );
        }
    }
}
add_action ( 'save_post', 'save_category_fields');


function checkbox_RA(){

    global $post;
    $custom = get_post_custom($post->ID);
    $RA_checkbox = isset($custom["RA_checkbox"][0]) ? true : false; 
?>

Publié au Recueil Administratif <input type="checkbox" name="RA_checkbox" <?php if( $RA_checkbox == true ) { ?>checked="checked"<?php } ?> />
<?php } 

add_action('save_post', 'save_ra_details');

function save_ra_details($term_id) {
	$RA_checkbox = get_post_meta( $term_id, 'RA_checkbox' );
	
	$taxonomy = 'hob_ra';	

	if(isset($_POST["RA_checkbox"]) && $_POST["RA_checkbox"] == 'on'){

			update_post_meta($term_id, "RA_checkbox", $_POST["RA_checkbox"]);

			wp_insert_term( 'OK', 'hob_ra' ); // Création d'un term du nom de l'input dans la taxonomy RA

			global $wpdb;
			$results = $wpdb->get_results( "SELECT MIN(term_taxonomy_id) as id FROM wp_term_taxonomy WHERE taxonomy = 'hob_ra'", OBJECT);
			$category_id = $results[0]->id;	

			wp_set_object_terms( $term_id, intval( $category_id ), 'hob_ra' );
		}
}


function hob_search_form( $form ) {
    ?>

<form method="post" id="hobsearchform" action="<?php echo home_url( '/' );?>/hob-ap/" >
    <div>
    	<input type="text" placeholder="Recherchez un acte" value="<?php echo get_search_query();?>" name="s" id="s" /> 
		<input type="submit" id="searchsubmit" value="<?php echo esc_attr__( 'Search' ) ;?>" />

		<!-- <div class="show_all" style="cursor:pointer;" onclick="see_more_cat(this)">				
			<p class="add_button" style="color:black;">Recherche avancée +</p>
		</div>
		
		<div id="js_selection" >

		<select id="select-rubrique" name="select-rubrique">
			<option class="first-option" value="-1">Sélectionnez une rubrique</option>
				<?php
				$taxonomy = 'hob_rubrique';
				$terms = get_terms($taxonomy, array('orderby' => 'name'));

				foreach($terms as $term) {
					echo '<option value="'.$term->term_id.'">'.$term->name.'</option>';
				} ?>
		</select>

		<select id="select-type" name="select-type">
			<option class="first-option" value="-1">Sélectionnez un type</option>
				<?php
				$taxonomy = 'hob_typecat';
				$terms = get_terms($taxonomy, array('orderby' => 'name'));

				foreach($terms as $term) {
					echo '<option value="'.$term->term_id.'">'.$term->name.'</option>';
				} ?>
		</select>


			 <label for="selecteur1">Rubrique :</label>
				<?php 

				$selected = wp_get_object_terms('hob_rubrique[]', $taxonomy, array('fields' => 'ids'));

					wp_dropdown_categories(array(
						"taxonomy" => "hob_rubrique",
						"class" => "selecteur1",
						"hide_if_empty" => false, 
						"name" => "hob_rubrique[]",
						'selected' => count($selected) >= 1 ? $selected[0] : '',
						"orderby" => "name", 
						"hierarchical" => 1, 
						"show_option_all" => "Sélectionnez une rubrique",
					)) ?>
						
			<label for="selecteur2">Type :</label>
				<?php
					wp_dropdown_categories(array(
						"taxonomy" => "hob_typecat",
						"class" => "selecteur2",
						"hide_if_empty" => false, 
						"name" => "hob_typecat[]",
						"orderby" => "name", 
						"hierarchical" => 1, 
						"show_option_all" => "Sélectionnez un type",
					));
				?> 

			<label for="date_cons">Date du conseil du :</label>
			<input type="date" id="start" name="date_cons_start"
				min="2016-01-01" max="<?php getdate()?>">
			
			<label for="date_cons">au :</label>
			<input type="date" id="end" name="date_cons_end"
				min="2016-01-01" max="<?php getdate()?>">
		</div> -->
    </div>
</form>

<script>

function see_more_cat(e){ 
    var element = e.nextElementSibling; 
   
    if(element.style.display == 'none'){ 
        element.style.display = "block"; 
        e.style.border.bottom = 'none'; 
        e.lastElementChild.textContent = "Réduire -";
    }else{
        element.style.display = "none";
        e.style.border.bottom = '2px solid gray';
        e.lastElementChild.textContent = "Recherche avancée +";
    }
}

</script>
<?php
    return '';
}
 add_filter( 'get_search_form', 'hob_search_form' );

 function hob_search_filter($query) {
	    if ( ! is_admin() && $query->is_search() && $query->is_main_query() && is_post_type_archive( 'hob-ap' ) ) {
		$rubrique = get_term_by('id', $_POST['select-rubrique'], 'hob_rubrique');
		$type = get_term_by('id', $_POST['select-type'], 'hob_typecat');

        if ( $rubrique != null) {
			$args = array(
				'post_type' => 'hob-ap',
				'tax_query' => array(
					'relation' => 'AND',
			array(
			   'taxonomy' => 'hob_rubrique',
			   'field'    => 'slug',
			   'terms'    =>  $rubrique->slug,
		   )
	   ));

	   $query = new WP_Query ($args);

	   $display_posts = $query->posts;

	   foreach ($display_posts as $display_post){
			var_dump($display_post);
	   }
	}

	if ($type != null) {
		$args = array(
			'post_type' => 'hob-ap',
			'tax_query' => array(
				'relation' => 'AND',
		array(
		   'taxonomy' => 'hob_typecat',
		   'field'    => 'slug',
		   'terms'    =>  $type->slug,
	   )
   ));

   $query = new WP_Query ($args);

   $display_posts = $query->posts;

   foreach ($display_posts as $display_post){
		var_dump($display_post);
   }
}
}
} 

//add_action( 'pre_get_posts', 'hob_search_filter' ); 

// Fonction permettant l'affichage des taxonomies à gauche par défaut lors de la créationd d'un post
add_filter( 'get_user_option_meta-box-order_hob-ap', 'display_hob_box' );
function display_hob_box( $order )
{
    return array(
        'normal'   => join( ",", array(
			'hob_typecatdiv',
			'hob_rubriquediv',
			'tagsdiv-hob_ra',
			'tagsdiv-hob_deliberation',
			'tagsdiv-hob_register',
			'tagsdiv-hob_page',
        ) ),
        'side'     => '',
        'advanced' => '',
    );
}